/*
 * Wire
 * Copyright (C) 2025 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 */
package com.wire.kalium.cryptography

interface MLSTransporter {
    /**
     * Send a message to the delivery service.
     */
    suspend fun sendMessage(mlsMessage: ByteArray): MlsTransportResponse

    /**
     * Send a commit bundle to the delivery service.
     */
    suspend fun sendCommitBundle(commitBundle: CommitBundle): MlsTransportResponse
}

sealed class MlsTransportResponse {

    /**
     * The message was accepted by the distribution service
     */
    data object Success : MlsTransportResponse()

    /**
     * A client should have consumed all incoming messages before re-trying.
     */
    data object Retry : MlsTransportResponse()

    /**
     * The message was rejected by the delivery service and there's no recovery.
     */
    data class Abort(val reason: String) : MlsTransportResponse()
}
