/*
 * Wire
 * Copyright (C) 2025 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 */
package com.wire.kalium.logic.feature.call.usecase

import com.wire.kalium.logic.data.call.Call
import com.wire.kalium.logic.data.call.CallRepository
import com.wire.kalium.logic.data.call.CallStatus
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.filter
import kotlinx.coroutines.flow.map

/**
 * This use case is responsible for observing the ongoing and incoming calls.
 */
interface ObserveOngoingAndIncomingCallsUseCase {
    suspend operator fun invoke(): Flow<List<Call>>
}

internal class ObserveOngoingAndIncomingCallsUseCaseImpl(
    private val callRepository: CallRepository
) : ObserveOngoingAndIncomingCallsUseCase {

    override suspend fun invoke(): Flow<List<Call>> {
        return callRepository.callsFlow().map {
            it.filter { call ->
                call.status == CallStatus.INCOMING || call.status == CallStatus.STILL_ONGOING
            }
        }.filter { it.isNotEmpty() }
    }
}
