/*
 * Wire
 * Copyright (C) 2024 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 */

package com.wire.kalium.logic.feature.publicuser

import com.wire.kalium.logic.data.user.OtherUser
import com.wire.kalium.logic.data.user.UserId
import com.wire.kalium.logic.data.user.UserRepository
import kotlinx.coroutines.flow.Flow

/**
 * Gets the public user profile of a contact
 */
interface GetKnownUserUseCase {
    /**
     * @param userId the user id of the contact
     * @return the [Flow] of [OtherUser] if successful
     */
    suspend operator fun invoke(userId: UserId): Flow<OtherUser?>
}

internal class GetKnownUserUseCaseImpl internal constructor(
    private val userRepository: UserRepository
) : GetKnownUserUseCase {

    // TODO(qol): Better handle nullable OtherUser?
    override suspend fun invoke(userId: UserId): Flow<OtherUser?> = userRepository.getKnownUser(userId)

}
