/*
 * Wire
 * Copyright (C) 2024 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 */
package com.wire.kalium.logic.util.arrangement.repository

import com.wire.kalium.common.error.StorageFailure
import com.wire.kalium.logic.configuration.server.ServerConfig
import com.wire.kalium.logic.configuration.server.ServerConfigRepository
import com.wire.kalium.logic.data.user.UserId
import com.wire.kalium.common.functional.Either
import io.mockative.Mock
import io.mockative.coEvery
import io.mockative.fake.valueOf
import io.mockative.matchers.AnyMatcher
import io.mockative.matchers.Matcher
import io.mockative.matches
import io.mockative.mock

internal interface ServerConfigRepositoryArrangement {
    @Mock
    val serverConfigRepository: ServerConfigRepository

    suspend fun withServerConfigForUser(
        result: Either<StorageFailure, ServerConfig>,
        userId: Matcher<UserId> = AnyMatcher(valueOf())
    ) {
        coEvery {
            serverConfigRepository.configForUser(matches { userId.matches(it) })
        }.returns(result)
    }
}

internal class ServerConfigRepositoryArrangementImpl : ServerConfigRepositoryArrangement {

    @Mock
    override val serverConfigRepository: ServerConfigRepository = mock(ServerConfigRepository::class)
}
